# unitorch.cli.models.roberta

## RobertaProcessor

!!! tip
    **`core/process/roberta`** is the section for configuration of RobertaProcessor.

::: unitorch.cli.models.roberta.RobertaProcessor

## RobertaForClassification

!!! tip
    **`core/model/classification/roberta`** is the section for configuration of RobertaForClassification.

::: unitorch.cli.models.roberta.RobertaForClassification

